define(
//begin v1.x content
({
	"nodeActions": "${nodeName} - handlinger",
	"selectContents": "Vælg indhold",
	"selectElement": "Vælg element",
	"deleteElement": "Slet element",
	"deleteContents": "Slet indhold",
	"moveStart": "Flyt markør til start",
	"moveEnd": "Flyt markør til slut"
})

//end v1.x content
);
